@@ -1,8 +1,5 @@
 /***************************************************************************
-
-                          elementdataviewer.cpp  -  description
-                             -------------------
-    copyright            : (C) 2004 by Carsten Niehaus
+    copyright            : (C) 2004, 2005  by Carsten Niehaus
     email                : cniehaus@kde.org
  ***************************************************************************/
 
@@ -16,45 +13,53 @@
  ***************************************************************************/
 
 #include "elementdataviewer.h"
+#include "element.h"
 #include "plotsetupwidget.h"
+#include "plotwidget.h"
+#include "kalziumdataobject.h"
+
 #include <klocale.h>
 #include <knuminput.h>
 #include <kcombobox.h>
 #include <kdebug.h>
+#include <kactioncollection.h>
+#include <kapplication.h>
 
 //QT-Includes
-#include <qframe.h>
 #include <qlayout.h>
 #include <qcheckbox.h>
+#include <qlabel.h>
 
-ElementDataViewer::ElementDataViewer( KalziumDataObject *data, QWidget *parent, const char* name )
+ElementDataViewer::ElementDataViewer( QWidget *parent, const char* name )
 	: KDialogBase( KDialogBase::Plain, 
-			i18n( "Visualize Data") , 
-			User1 | Close,
+			i18n( "Plot Data") , 
+			Help | User1 | Close,
 			User1,
 			parent, name )
 {
-	kdDebug() << "ElementDataViewer" << endl;
-	
-	d = data;
+	d = KalziumDataObject::instance();
 
 	yData = new AxisData();
 	
-	QFrame *page = plainPage();
-	QHBoxLayout *hlay = new QHBoxLayout(page, 0, spacingHint() );
-	QVBoxLayout *vlay = new QVBoxLayout(hlay, 0 );
-	m_pPlotSetupWidget = new PlotSetupWidget( page, "psw" );	
-	m_pPlotWidget = new PlotWidget( 0.0,12.0,0.0,22.0, page, "plotwidget" );
+	QHBoxLayout *layout = new QHBoxLayout(plainPage(), 0, KDialog::spacingHint() );
+
+	m_pPlotSetupWidget = new PlotSetupWidget( plainPage(), "plotsetup" );	
+	m_pPlotSetupWidget->from->setMaxValue( d->numberOfElements() - 1 );
+	m_pPlotSetupWidget->to->setMaxValue( d->numberOfElements() );
+	m_pPlotWidget = new PlotWidget( 0.0, 12.0 ,0.0 ,22.0, plainPage(), "plotwidget" );
 	m_pPlotWidget->setYAxisLabel(" ");
+	m_pPlotWidget->setMinimumWidth( 200 );
+	m_pPlotWidget->resize( 400, m_pPlotWidget->height() );
 
-	hlay->addWidget( m_pPlotSetupWidget );
-	vlay->addWidget( m_pPlotWidget);
+	layout->addWidget( m_pPlotSetupWidget );
+	layout->addWidget( m_pPlotWidget );
+	layout->setStretchFactor( m_pPlotSetupWidget, 0 );
+	layout->setStretchFactor( m_pPlotWidget, 1 );
 
-	/*
-	 * setup the list of names
-	 **/
+	// setup the list of names
 	EList::iterator it = d->ElementList.begin();
-	for( ; it != d->ElementList.end() ; ++it )
+	const EList::iterator itEnd = d->ElementList.end();
+	for( ; it != itEnd ; ++it )
 	{
 		names.append( (*it)->elname() );
 	}
@@ -63,9 +68,31 @@ ElementDataViewer::ElementDataViewer( KalziumDataObject *data, QWidget *parent,
 
 	setButtonText( User1, i18n("&Plot") );
 
-	connect ( m_pPlotSetupWidget->showNames, SIGNAL( toggled(bool)), this, SLOT(slotUser1()));
+	m_actionCollection = new KActionCollection(this);
+	KStdAction::quit(this, SLOT(slotClose()), m_actionCollection);	
+
+	connect ( m_pPlotSetupWidget->KCB_y,         SIGNAL( activated(int) ),
+			  this,                              SLOT( drawPlot()) );
+
+	connect ( m_pPlotSetupWidget->connectPoints, SIGNAL( toggled(bool) ),
+			  this,                              SLOT( drawPlot()) );
+	connect ( m_pPlotSetupWidget->showNames,     SIGNAL( toggled(bool) ),
+			  this,                              SLOT( drawPlot()) );
+
+	// Draw the plot so that the user doesn't have to press the "Plot"
+	// button to seee anything.
+	drawPlot();
 }
 
+void ElementDataViewer::slotHelp()
+{
+	emit helpClicked();
+	if ( kapp )
+		kapp->invokeHelp ( "plot_data", "kalzium" );
+}
+
+// Reimplement slotUser1 from KDialogBase
+
 void ElementDataViewer::slotUser1()
 {
 	kdDebug() << "slotUser1" << endl;
@@ -73,6 +100,7 @@ void ElementDataViewer::slotUser1()
 	drawPlot();
 }
 
+
 void ElementDataViewer::setLimits(int f, int t)
 {
 	kdDebug() << "setLimits()" << endl;
@@ -80,10 +108,7 @@ void ElementDataViewer::setLimits(int f, int t)
 	double minY = yData->value(f);
 	double maxY = yData->value(f);
 
-	int _currentVal = f;
-	int _to = t;
-	
-	while( _currentVal < _to )
+	for ( int _currentVal = f; _currentVal <= t; _currentVal++ )
 	{
 		double v = yData->value( _currentVal );
 		
@@ -91,11 +116,12 @@ void ElementDataViewer::setLimits(int f, int t)
 			minY = v;
 		if( maxY < v)
 			maxY = v;
-
-		_currentVal++;
 	}
 	
-	m_pPlotWidget->setLimits( (double)f, (double)t, minY, maxY );
+	// try to put a small padding to make the points on the axis visible
+	double dx = ( t - f + 1 ) / 25 + 1.0;
+	double dy = ( maxY - minY ) / 10.0;
+	m_pPlotWidget->setLimits( f - dx, t + dx, minY - dy, maxY + dy );
 }
 
 void ElementDataViewer::paintEvent(QPaintEvent*)
@@ -126,8 +152,6 @@ void ElementDataViewer::slotZoomOut(){}
 
 void ElementDataViewer::setupAxisData()
 {
-	kdDebug() << "setupAxisData()" << endl;
-
 	DoubleList l;
 
 	const int selectedData = m_pPlotSetupWidget->KCB_y->currentItem();
@@ -136,97 +160,88 @@ void ElementDataViewer::setupAxisData()
 	yData->m_currentDataType = selectedData;
 
 	EList::iterator it = d->ElementList.begin();
+	const EList::iterator itEnd = d->ElementList.end();
 	switch(selectedData)
 	{
-		case AxisData::WEIGHT:
-			for( ; it != d->ElementList.end() ; ++it ) {
-				double value = (*it)->weight();
-				if( value != -1 )
+		case AxisData::MASS:
+			for( ; it != itEnd ; ++it ) {
+				double value = (*it)->mass();
+				if( value > 0.0 )
 				  l.append( value );
 				else
 				  l.append( 0.0 );
-				m_pPlotWidget->setYAxisLabel(i18n("Atomic Weight [u]"));
 			}
+			m_pPlotWidget->setYAxisLabel(i18n("Atomic Mass [u]"));
 			break;
 		case AxisData::MEANWEIGHT:
-			for( ; it != d->ElementList.end() ; ++it ) {
-				double value =(*it)->meanweight();
-				if( value != -1 )
+			for( ; it != itEnd ; ++it ) {
+				double value =(*it)->meanmass();
+				if( value > 0.0 )
 				  l.append( value );
 				else
 				  l.append( 0.0 );
-				m_pPlotWidget->setYAxisLabel(i18n("Mean Weight [u]"));
 			}
+			m_pPlotWidget->setYAxisLabel(i18n("Mean Mass [u]"));
 			break;
 		case AxisData::DENSITY:
-			for( ; it != d->ElementList.end() ; ++it ) {
+			for( ; it != itEnd ; ++it ) {
 				double value =(*it)->density();
-				if( value != -1 )
+				if( value > 0.0 )
 				  l.append( value );
 				else
 				  l.append( 0.0 );
-				m_pPlotWidget->setYAxisLabel(i18n("Density"));
-			}
-			break;
-		case AxisData::IE1:
-			for( ; it != d->ElementList.end() ; ++it ) {
-				double value = (*it)->ie();
-				if( value != -1 )
-				  l.append( value );
-				else
-				  l.append( 0.0 );
-				m_pPlotWidget->setYAxisLabel(i18n("1. Ionization Energy"));
-			}
-			break;
-		case AxisData::IE2:
-			for( ; it != d->ElementList.end() ; ++it ) {
-				double value = (*it)->ie2();
-				if( value != -1 )
-				  l.append( value );
-				else
-				  l.append( 0.0 );
-				m_pPlotWidget->setYAxisLabel(i18n("2. Ionization Energy"));
 			}
+			m_pPlotWidget->setYAxisLabel(i18n("Density"));
 			break;
 		case AxisData::EN:
-			for( ; it != d->ElementList.end() ; ++it ) {
+			for( ; it != itEnd ; ++it ) {
 				double value = (*it)->electroneg();
-				if( value != -1 )
+				if( value > 0.0 )
 				  l.append( value );
 				else
 				  l.append( 0.0 );
-				m_pPlotWidget->setYAxisLabel(i18n("Electronegativity"));
 			}
+			m_pPlotWidget->setYAxisLabel(i18n("Electronegativity"));
 			break;
 		case AxisData::MELTINGPOINT:
-			for( ; it != d->ElementList.end() ; ++it ) {
+			for( ; it != itEnd ; ++it ) {
 				double value = (*it)->melting();
-				if( value != -1 )
+				if( value > 0.0 )
 				  l.append( value );
 				else
 				  l.append( 0.0 );
-				m_pPlotWidget->setYAxisLabel(i18n("Melting Point [K]"));
 			}
+			m_pPlotWidget->setYAxisLabel(i18n("Melting Point [K]"));
 			break;
 		case AxisData::BOILINGPOINT:
-			for( ; it != d->ElementList.end() ; ++it ) {
-				double value = (*it)->electroneg();
-				if( value != -1 )
+			for( ; it != itEnd ; ++it ) {
+				double value = (*it)->boiling();
+				if( value > 0.0 )
 				  l.append( value );
 				else
 				  l.append( 0.0 );
-				m_pPlotWidget->setYAxisLabel(i18n("Boiling Point [K]"));
 			}
+			m_pPlotWidget->setYAxisLabel(i18n("Boiling Point [K]"));
 			break;
 		case AxisData::ATOMICRADIUS:
-			for( ; it != d->ElementList.end() ; ++it ) {
-				double value = (*it)->radius();
-				if( value != -1 )
+			for( ; it != itEnd ; ++it ) {
+				double value = (*it)->radius( Element::ATOMIC );
+				if( value > 0.0 )
 				  l.append( value );
 				else
 				  l.append( 0.0 );
-				m_pPlotWidget->setYAxisLabel(i18n("Atomic Radius [pm]"));
 			}
+			m_pPlotWidget->setYAxisLabel(i18n("Atomic Radius [pm]"));
+			break;
+		case AxisData::COVALENTRADIUS:
+			for( ; it != itEnd ; ++it ) {
+				double value = (*it)->radius( Element::COVALENT );
+				if( value > 0.0 )
+				  l.append( value );
+				else
+				  l.append( 0.0 );
+			}
+			m_pPlotWidget->setYAxisLabel(i18n("Covalent Radius [pm]"));
 			break;
 	}
 
@@ -251,15 +266,13 @@ void ElementDataViewer::drawPlot()
 	/*
 	 * if the user selected the elements 20 to 30 the list-values are 19 to 29!!!
 	 */
-	int from = m_pPlotSetupWidget->from->value();
-	int to = m_pPlotSetupWidget->to->value();
-	kdDebug() << "from :" << from << endl;
-	kdDebug() << "to :" << to << endl;
+	const int from = m_pPlotSetupWidget->from->value();
+	const int to = m_pPlotSetupWidget->to->value();
 	
 	/*
 	 * The number of elements. #20 to 30 are 30-20+1=11 Elements
 	 */
-	int num = to-from+1;
+	const int num = to-from+1;
 	
 	setLimits(from,to);
 
@@ -270,55 +283,64 @@ void ElementDataViewer::drawPlot()
 	bool connectPoints = m_pPlotSetupWidget->connectPoints->isChecked();
 
 	if ( connectPoints )
-	{
 		m_pPlotWidget->setConnection( true );
-		kdDebug() << "setConnection ist wahr" << endl;
-	}
 	else
-	{
 		m_pPlotWidget->setConnection( false );
-		kdDebug() << "setConnection ist falsch" << endl;
-	}
 		
 	/*
 	 * reserve the memory for the KPlotObjects
 	 */
+	//TODO QT4 replace QMemArray with QVector
 	QMemArray<KPlotObject*> dataPoint(num);
 	QMemArray<KPlotObject*> dataPointLabel(num);
 
 	int number = 0;
 
+	double max = 0.0, av = 0.0;
+	double min = yData->value( 1 );
+
 	/*
 	 * iterate for example from element 20 to 30 and contruct
 	 * the KPlotObjects
 	 */
-	kdDebug() << "start the plotting with creating the KPlotObjects" << endl;
 	for( int i = from; i < to+1 ; i++ )
 	{
-		dataPoint[number] = new KPlotObject( "whocares", "Blue", KPlotObject::POINTS, 4, KPlotObject::CIRCLE );
-		dataPoint[number]->addPoint( new DPoint( (double)i , yData->value( i ) ) );
-		m_pPlotWidget->addObject( dataPoint[ number ] );
+		double v = yData->value( i );
 
-		if (showNames)
+		if ( v >= 0.0 )
 		{
-		  dataPointLabel[number] = new KPlotObject( *(names.at(i)), "Red", KPlotObject::LABEL );
-		  dataPointLabel[number]->addPoint( new DPoint( (double)i , yData->value( i ) ) );
-		  m_pPlotWidget->addObject( dataPointLabel[number] );
+			if ( v < min )
+				min = v;
+			if ( v > max )
+				max = v;
+			av += v;
+
+			dataPoint[number] = new KPlotObject( "whocares", "Blue", KPlotObject::POINTS, 4, KPlotObject::CIRCLE );
+			dataPoint[number]->addPoint( new DPoint( (double)i , v ) );
+			m_pPlotWidget->addObject( dataPoint[ number ] );
+
+			if (showNames)
+			{
+				dataPointLabel[number] = new KPlotObject( *(names.at(i-1)), "Red", KPlotObject::LABEL );
+				dataPointLabel[number]->addPoint( new DPoint( (double)i , yData->value( i ) ) );
+				m_pPlotWidget->addObject( dataPointLabel[number] );
+			}
 		}
-		
 		number++;
 	}
-	kdDebug() << "plotting ended" << endl;
+
+	//now set the values for the min, max and avarage value
+	m_pPlotSetupWidget->aValue->setText( QString::number( av/number ) );
+	m_pPlotSetupWidget->minValue->setText( QString::number( min ) );
+	m_pPlotSetupWidget->maxValue->setText( QString::number( max ) );
 }
 
 void ElementDataViewer::initData()
 {
-	kdDebug() << "initData()" << endl;
-	
 	setupAxisData();
 }
 
-///////////////////////////////////////////////7
+///////////////////////////////////////////////
 
 AxisData::AxisData()
 {}
