@@ -5,7 +5,7 @@
                            orbitswidget.h  -  description
                              -------------------
     begin                : June 2003
-    copyright            : (C) 2003, 2004 by Carsten Niehaus
+    copyright            : (C) 2003, 2004, 2005 by Carsten Niehaus
     email                : cniehaus@kde.org
  ***************************************************************************/
 
@@ -31,7 +31,9 @@ class OrbitsWidget : public QWidget
 	Q_OBJECT
 
 	public:
-		OrbitsWidget( const int Elemno , QWidget *parent=0 , const char *name =0 );
+		OrbitsWidget( QWidget *parent=0 , const char *name =0 );
+
+		void setElementNumber( const int num );
 
 	private:
 		/**
