@@ -177,10 +177,10 @@ void KEducaView::slotButtonSave()
         }
 
         if ( KIO::NetAccess::exists( newURL, false, this ) ) { // this file exists => ask for confirmation
-            bOk = KMessageBox::questionYesNo( this,
+            bOk = KMessageBox::warningContinueCancel( this,
                                               i18n("A document with this name already exists.\n"\
                                                    "Do you want to overwrite it?"),
-                                              i18n("Warning") ) == KMessageBox::Yes;
+                                              i18n("Warning"), i18n("Overwrite") ) == KMessageBox::Continue;
         }
     } while ( !bOk );
 
