@@ -206,7 +206,7 @@ private:
     KURL _currentURL;
     /** the temporary file to which the document is saved, NULL if no temporary file is needed */
     KTempFile *_tmpfile;
-    /** the temporary imgae file */
+    /** the temporary image file */
     QString _tmpfileImage;
     /** Total Questions */
     uint _totalQuestions;
@@ -236,13 +236,6 @@ protected slots:
 signals:
 /* Stolen from kparts */
 
-    /**
-   * The part emits this when starting data.
-   * If using a KIO::Job, it sets the job in the signal, so that
-   * progress information can be shown. Otherwise, job is 0.
-   **/
-  void started( KIO::Job * );
-
   /**
    * Emit this when you have completed loading data.
    * Hosting apps will want to know when the process of loading the data
