@@ -14,13 +14,14 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
    USA
 **/
 
 #include "kigpainter.h"
 
 #include "../kig/kig_view.h"
+#include "../kig/kig_document.h"
 #include "../misc/goniometry.h"
 #include "../objects/object_holder.h"
 #include "../objects/curve_imp.h"
@@ -197,7 +198,6 @@ void KigPainter::textOverlay( const QRect& r, const QString s, int textFlags, in
 {
   //  kdDebug() << Rect::fromQRect( mP.boundingRect( r, textFlags, s, len ) ) << endl;
   QRect newr( mP.boundingRect( r, textFlags, s, len ) );
-  newr.moveBy( -2, -2 );
   newr.setWidth( newr.width() + 4 );
   newr.setHeight( newr.height() + 4 );
   mOverlay.push_back( newr );
@@ -207,7 +207,6 @@ const Rect KigPainter::boundingRect( const Rect& r, const QString s,
                                      int f, int l ) const
 {
   QRect qr = mP.boundingRect( toScreen( r ), f, s, l );
-  qr.moveBy( -2, -2 );
   qr.setWidth( qr.width() + 4 );
   qr.setHeight( qr.height() + 4 );
   return fromScreen( qr );
@@ -264,36 +263,69 @@ void KigPainter::setBrushColor( const QColor& c )
   mP.setBrush( QBrush( brushColor, brushStyle ) );
 }
 
+bool KigPainter::getNightVision( ) const
+{
+  return mdoc.getNightVision();
+}
+
 QColor KigPainter::getColor() const
 {
   return color;
 }
 
+/*
 static void setContains( QRect& r, const QPoint& p )
 {
   if ( r.left() > p.x() ) r.setLeft( p.x() );
   if ( r.right() < p.x() ) r.setRight( p.x() );
   // this is correct, i think.  In qt the bottom has the highest y
   // coord...
-  if ( r.bottom() < p.y() ) r.setBottom( p.x() );
-  if ( r.top() < p.y() ) r.setTop( p.x() );
+  if ( r.bottom() > p.y() ) r.setBottom( p.y() );
+  if ( r.top() < p.y() ) r.setTop( p.y() );
 }
+*/
 
 void KigPainter::drawPolygon( const std::vector<QPoint>& pts,
                               bool winding, int index, int npoints )
 {
-  QRect sr;
+  QPen oldpen = mP.pen();
+  QBrush oldbrush = mP.brush();
+  setBrush( QBrush( color, Dense4Pattern ) );
+  setPen( Qt::NoPen );
   // i know this isn't really fast, but i blame it all on Qt with its
   // stupid container classes... what's wrong with the STL ?
   QPointArray t( pts.size() );
   int c = 0;
   for( std::vector<QPoint>::const_iterator i = pts.begin(); i != pts.end(); ++i )
   {
-    setContains( sr, *i );
     t.putPoints( c++, 1, i->x(), i->y() );
   };
   mP.drawPolygon( t, winding, index, npoints );
-  mOverlay.push_back( sr );
+  setPen( oldpen );
+  setBrush( oldbrush );
+  if( mNeedOverlay ) mOverlay.push_back( t.boundingRect() );
+}
+
+void KigPainter::drawArea( const std::vector<Coordinate>& pts, bool border )
+{
+  QPen oldpen = mP.pen();
+  QBrush oldbrush = mP.brush();
+  setBrush( QBrush( color, SolidPattern ) );
+  if ( border )
+    setPen( QPen( color, width == -1 ? 1 : width ) );
+  else
+    setPen( Qt::NoPen );
+  QPointArray t( pts.size() );
+  int c = 0;
+  for( std::vector<Coordinate>::const_iterator i = pts.begin(); i != pts.end(); ++i )
+  {
+    QPoint p = toScreen( *i );
+    t.putPoints( c++, 1, p.x(), p.y() );
+  }
+  mP.drawPolygon( t );
+  setPen( oldpen );
+  setBrush( oldbrush );
+  if( mNeedOverlay ) mOverlay.push_back( t.boundingRect() );
 }
 
 Rect KigPainter::window()
@@ -475,7 +507,7 @@ void KigPainter::drawFilledRect( const QRect& r )
 
 void KigPainter::drawTextStd( const QPoint& p, const QString& s )
 {
-  if ( ! s ) return;
+  if ( s.isNull() ) return;
   // tf = text formatting flags
   int tf = AlignLeft | AlignTop | DontClip | WordBreak;
   // we need the rect where we're going to paint text
@@ -602,16 +634,22 @@ void KigPainter::drawAngle( const Coordinate& cpoint, const double dstartangle,
   vect = vect * 6 / vectlen;
   orthvect = orthvect * 6 / vectlen;
 
-  std::vector<QPoint> arrow;
-  arrow.push_back( end );
-  arrow.push_back( end + orthvect + vect );
-  arrow.push_back( end + orthvect - vect );
+  QPointArray arrow( 3 );
+  arrow.setPoint( 0, end );
+  arrow.setPoint( 1, end + orthvect + vect );
+  arrow.setPoint( 2, end + orthvect - vect );
+//  std::vector<QPoint> arrow;
+//  arrow.push_back( end );
+//  arrow.push_back( end + orthvect + vect );
+//  arrow.push_back( end + orthvect - vect );
 
   setBrushStyle( Qt::SolidPattern );
-  drawPolygon( arrow );
+//  drawPolygon( arrow );
+  mP.drawPolygon( arrow, false, 0, -1 );
 
 //  if ( mNeedOverlay ) mOverlay.push_back( toScreen( r ) );
-  setWholeWinOverlay();
+  setWholeWinOverlay();   //mp: ugly! why not compute a correct overlay?
+                          //    mOverlay.push_back( arrow.boundingRect() ); 
 }
 
 void KigPainter::drawPolygon( const std::vector<Coordinate>& pts,
@@ -892,11 +930,20 @@ void KigPainter::drawArc( const Coordinate& center, const double radius,
   const int startangle = static_cast<int>( Goniometry::convert( 16 * dstartangle, Goniometry::Rad, Goniometry::Deg ) );
   const int angle = static_cast<int>( Goniometry::convert( 16 * dangle, Goniometry::Rad, Goniometry::Deg ) );
 
-  Rect krect( 0, 0, 2*radius, 2*radius );
-  krect.setCenter( center );
-  QRect rect = toScreen( krect );
+  if ( angle <= 16 )
+  {
+    Coordinate a = center + radius * Coordinate( cos( dstartangle ), sin( dstartangle ));
+    Coordinate b = center + radius * Coordinate( cos( dstartangle + dangle ), sin( dstartangle + dangle ));
+    drawSegment ( a , b );
+  } 
+  else
+  { 
+    Rect krect( 0, 0, 2*radius, 2*radius );
+    krect.setCenter( center );
+    QRect rect = toScreen( krect );
 
-  mP.drawArc( rect, startangle, angle );
-  setWholeWinOverlay();
+    mP.drawArc( rect, startangle, angle );
+    setWholeWinOverlay();
+  }
 }
 
