@@ -101,7 +101,7 @@ void KStars::zoom( double z ) {
 }
 
 void KStars::setLocalTime(int yr, int mth, int day, int hr, int min, int sec) {
-	data()->changeDateTime( KStarsDateTime( ExtDate(yr, mth, day), QTime(hr,min,sec) ) );
+	data()->changeDateTime( geo()->LTtoUT( KStarsDateTime( ExtDate(yr, mth, day), QTime(hr,min,sec) ) ) );
 }
 
 void KStars::waitFor( double t ) {
@@ -182,6 +182,39 @@ void KStars::setGeoLocation( QString city, QString province, QString country ) {
 	}
 }
 
+void KStars::readConfig() {
+	//Load config file values into Options object
+	Options::self()->readConfig();
+
+	applyConfig();
+
+	//Reset date, if one was stored
+	if ( data()->StoredDate.isValid() ) {
+		data()->changeDateTime( geo()->LTtoUT( data()->StoredDate ) );
+		data()->StoredDate.setDJD( (long double)INVALID_DAY ); //invalidate StoredDate
+	}
+
+	map()->forceUpdate();
+}
+
+void KStars::writeConfig() {
+	Options::writeConfig();
+
+	//Store current simulation time
+	data()->StoredDate.setDJD( data()->lt().djd() );
+}
+
+QString KStars::getOption( const QString &name ) {
+	//Some config items are not stored in the Options object while 
+	//the program is running; catch these here and returntheir current value.
+	if ( name == "FocusRA" ) { return QString::number( map()->focus()->ra()->Hours(), 'f', 6 ); }
+	if ( name == "FocusDec" ) { return QString::number( map()->focus()->dec()->Degrees(), 'f', 6 ); }
+
+	KConfigSkeletonItem *it = Options::self()->findItem( name );
+	if ( it ) return it->property().toString();
+	else return QString::null;
+}
+
 void KStars::changeViewOption( const QString op, const QString val ) {
 	bool bOk(false), nOk(false), dOk(false);
 
@@ -752,15 +785,37 @@ void KStars::waitForINDIAction(QString deviceName, QString action)
 }
 
 	
-void KStars::setINDIFocusSpeed(QString deviceName, QString action)
+void KStars::setINDIFocusSpeed(QString deviceName, unsigned int speed)
 {
+  INDI_D *dev;
+  INDI_P *prop;
+  INDI_E *el;
+
   if (!indidriver || !indimenu)
   {
     kdDebug() << "setINDIFocusSpeed: establishINDI() failed." << endl;
     return;
   }
 
-  setINDIAction(deviceName, action);
+  dev = indimenu->findDevice(deviceName);
+  if (!dev)
+    dev = indimenu->findDeviceByLabel(deviceName);
+  if (!dev)
+  {
+    kdDebug() << "Device " << deviceName << " not found!" << endl;
+    return;
+  }
+  
+  prop = dev->findProp("FOCUS_SPEED");
+  if (!prop) return;
+  
+  el   = prop->findElement("SPEED");
+  if (!el) return;
+  if (!el->write_w) return;
+  
+  el->write_w->setText(QString("%1").arg(speed));
+
+  prop->newText();
 
 }
 
@@ -774,9 +829,9 @@ void KStars::startINDIFocus(QString deviceName, int focusDir)
   }
 
   if (focusDir == 0)
-    setINDIAction(deviceName, "FOCUS_IN");
+    setINDIAction(deviceName, "IN");
   else if (focusDir == 1)
-    setINDIAction(deviceName, "FOCUS_OUT");
+    setINDIAction(deviceName, "OUT");
 
 }
 
@@ -882,10 +937,10 @@ void KStars::startINDIExposure(QString deviceName, int timeout)
     return;
   }
   
-  prop = dev->findProp("EXPOSE_DURATION");
+  prop = dev->findProp("CCD_EXPOSE_DURATION");
   if (!prop) return;
   
-  el   = prop->findElement("EXPOSE_S");
+  el   = prop->findElement("EXPOSE_DURATION");
   if (!el) return;
   
   if (el->write_w)
@@ -897,6 +952,42 @@ void KStars::startINDIExposure(QString deviceName, int timeout)
   prop->newText();
   
 }
+
+void KStars::setINDIFilterNum(QString deviceName, int filter_num)
+{
+  INDI_D *dev;
+  INDI_P *prop;
+  INDI_E *el;
+  
+  if (!indidriver || !indimenu)
+  {
+    kdDebug() << "setINDIFilterNum: establishINDI() failed." << endl;
+    return;
+  }
+  
+  dev = indimenu->findDevice(deviceName);
+  if (!dev)
+    dev = indimenu->findDeviceByLabel(deviceName);
+  if (!dev)
+  {
+    kdDebug() << "Device " << deviceName << " not found!" << endl;
+    return;
+  }
+  
+  prop = dev->findProp("FILTER_SLOT");
+  if (!prop) return;
+  
+  el   = prop->findElement("SLOT");
+  if (!el) return;
+  
+  if (el->write_w)
+    el->write_w->setText(QString("%1").arg(filter_num));
+  else if (el->spin_w)
+    el->spin_w->setValue(filter_num);
+  
+  prop->newText();
+  
+}
 		
 void KStars::setINDIUTC(QString deviceName, QString UTCDateTime)
 {
