@@ -49,10 +49,11 @@
 #include "ksasteroid.h"
 #include "kscomet.h"
 #include "starobject.h"
+#include "customcatalog.h"
 
 SkyMap::SkyMap(KStarsData *d, QWidget *parent, const char *name )
 	: QWidget (parent,name), computeSkymap(true), angularDistanceMode(false),
-		ksw(0), data(d), pmenu(0), sky(0), IBoxes(0), 
+		ksw(0), data(d), pmenu(0), sky(0), sky2(0), IBoxes(0), 
 		ClickedObject(0), FocusObject(0), TransientObject(0),
 		starpix(0), pts(0), sp(0)
 {
@@ -85,6 +86,7 @@ SkyMap::SkyMap(KStarsData *d, QWidget *parent, const char *name )
 	FocusObject = NULL;
 
 	sky = new QPixmap();
+	sky2 = new QPixmap();
 	pmenu = new KSPopupMenu( ksw );
 	
 	//Initialize Transient label stuff
@@ -133,6 +135,7 @@ SkyMap::~SkyMap() {
 	delete pts;
 	delete sp;
 	delete sky;
+	delete sky2;
 	delete pmenu;
 	delete IBoxes;
 
@@ -155,27 +158,32 @@ SkyMap::~SkyMap() {
 void SkyMap::setGeometry( int x, int y, int w, int h ) {
 	QWidget::setGeometry( x, y, w, h );
 	sky->resize( w, h );
+	sky2->resize( w, h );
 }
 
 void SkyMap::setGeometry( const QRect &r ) {
 	QWidget::setGeometry( r );
 	sky->resize( r.width(), r.height() );
+	sky2->resize( r.width(), r.height() );
 }
 
 
-void SkyMap::showFocusCoords( void ) {
-	//display object info in infoBoxes
-	QString oname;
-	oname = i18n( "nothing" );
-	if ( focusObject() != NULL && Options::isTracking() ) 
-		oname = focusObject()->translatedLongName();
-	
-	infoBoxes()->focusObjChanged(oname);
+void SkyMap::showFocusCoords( bool coordsOnly ) {
+	if ( ! coordsOnly ) {
+		//display object info in infoBoxes
+		QString oname;
+		oname = i18n( "nothing" );
+		if ( focusObject() != NULL && Options::isTracking() ) 
+			oname = focusObject()->translatedLongName();
+		
+		infoBoxes()->focusObjChanged(oname);
+	}
 
 	if ( Options::useAltAz() && Options::useRefraction() ) {
 		SkyPoint corrFocus( *(focus()) );
 		corrFocus.setAlt( refract( focus()->alt(), false ) );
 		corrFocus.HorizontalToEquatorial( data->LST, data->geo()->lat() );
+		corrFocus.setAlt( refract( focus()->alt(), true ) );
 		infoBoxes()->focusCoordChanged( &corrFocus );
 	} else {
 		infoBoxes()->focusCoordChanged( focus() );
@@ -315,13 +323,13 @@ SkyObject* SkyMap::objectNearest( SkyPoint *p ) {
 	int icust_min = -1;
 	int icust_cat = -1;
 
-	for ( register unsigned int j=0; j<Options::catalogCount(); ++j ) {
+	for ( register unsigned int j=0; j< data->CustomCatalogs.count(); ++j ) {
 		if ( Options::showCatalog()[j] ) {
-			QPtrList<DeepSkyObject> cat = data->CustomCatalogs[ Options::catalogName()[j] ];
+			QPtrList<SkyObject> catList = data->CustomCatalogs.at(j)->objList();
 
-			for ( register unsigned int i=0; i<cat.count(); ++i ) {
+			for ( register unsigned int i=0; i<catList.count(); ++i ) {
 				//test RA and dec to see if this object is roughly nearby
-				SkyObject *test = (SkyObject *)cat.at(i);
+				SkyObject *test = (SkyObject *)catList.at(i);
 				double dRA = test->ra()->Hours()-p->ra()->Hours();
 				double dDec = test->dec()->Degrees()-p->dec()->Degrees();
 				double f = 15.0*cos( test->dec()->radians() );
@@ -385,7 +393,7 @@ SkyObject* SkyMap::objectNearest( SkyPoint *p ) {
 		icat = 3; //set catalog to solar system
 	}
 
-	QPtrList<DeepSkyObject> cat;
+	QPtrList<SkyObject> cat;
 
 	switch (icat) {
 		case 0: //star
@@ -397,7 +405,7 @@ SkyObject* SkyMap::objectNearest( SkyPoint *p ) {
 			break;
 
 		case 2: //Custom Catalog Object
-			cat = data->CustomCatalogs[ Options::catalogName()[icust_cat] ];
+			cat = data->CustomCatalogs.at(icust_cat)->objList();
 			return cat.at(icust_min);
 			break;
 
@@ -493,7 +501,7 @@ void SkyMap::slotCenter( void ) {
 		QString caption = i18n( "Requested Position Below Horizon" );
 		QString message = i18n( "The requested position is below the horizon.\nWould you like to go there anyway?" );
 		if ( KMessageBox::warningYesNo( this, message, caption,
-				KStdGuiItem::yes(), KStdGuiItem::no(), "dag_focus_below_horiz" )==KMessageBox::No ) {
+				i18n("Go Anyway"), i18n("Keep Position"), "dag_focus_below_horiz" )==KMessageBox::No ) {
 			setClickedObject( NULL );
 			setFocusObject( NULL );
 			Options::setIsTracking( false );
@@ -530,9 +538,15 @@ void SkyMap::slotCenter( void ) {
 		setDestination( focusPoint() );
 	}
 
+	focusPoint()->EquatorialToHorizontal( data->LST, data->geo()->lat() );
+
 	//display coordinates in statusBar
 	if ( ksw ) {
-		QString s = focusPoint()->az()->toDMSString() + ",  " + focusPoint()->alt()->toDMSString(true);
+		QString sX = focusPoint()->az()->toDMSString();
+		QString sY = focusPoint()->alt()->toDMSString(true);
+		if ( Options::useAltAz() && Options::useRefraction() )
+			sY = refract( focusPoint()->alt(), true ).toDMSString(true);
+		QString s = sX + ",  " + sY;
 		ksw->statusBar()->changeItem( s, 1 );
 		s = focusPoint()->ra()->toHMSString() + ",  " + focusPoint()->dec()->toDMSString(true);
 		ksw->statusBar()->changeItem( s, 2 );
@@ -1014,7 +1028,7 @@ QPoint SkyMap::getXY( SkyPoint *o, bool Horiz, bool doRefraction, double scale )
   }
 
 	//Convert dX, Y coords to screen pixel coords.
-	#if ( __GLIBC__ >= 2 && __GLIBC_MINOR__ >=1 )
+	#if ( __GLIBC__ >= 2 && __GLIBC_MINOR__ >=1 ) && !defined(__UCLIBC__)
 	//GNU version
 	sincos( dX, &sindX, &cosdX );
 	sincos( Y, &sinY, &cosY );
