@@ -104,7 +104,7 @@ bool KVerbosDoc::saveModified()
     KVerbosApp *win=(KVerbosApp *) parent();
     int want_save = KMessageBox::warningYesNoCancel(win,
                 i18n("The current file has been modified.\nDo you want to save it?"),
-                i18n("Warning"));
+                i18n("Warning"),KStdGuiItem::save(),KStdGuiItem::discard());
     switch(want_save)
     {
       // ich habe die Nummern gegenber den originalen Nummern in der case-Anweisung
@@ -165,7 +165,7 @@ bool KVerbosDoc::openDocument(const KURL& url, const char *format /*=0*/)
 	QFile file(url.path());
 	if ( file.open(IO_ReadOnly) ) {    // file opened successfully
 		deleteContents();
-	if ((url.filename().right(4) == "html")||(url.filename().right(3) == "htm"))
+	if ((url.fileName().right(4) == "html")||(url.fileName().right(3) == "htm"))
 	{
 		// qWarning("ffnen eines HTML-files");
 		b = openDocHTML(file);
@@ -423,7 +423,7 @@ bool KVerbosDoc::saveDocument(const KURL& url, const char *format /*=0*/)
 	QFile file(url.path());
 	if ( file.open(IO_WriteOnly) )
 	{    // file opened successfully
-		if ((url.filename().right(4) == "html")||(url.filename().right(3) == "htm"))
+		if ((url.fileName().right(4) == "html")||(url.fileName().right(3) == "htm"))
 		{
 			// qWarning("als HTML speichern");
 			b = saveDocHTML(file);
@@ -450,12 +450,12 @@ bool KVerbosDoc::saveDocHTML(QFile &f)
   t << "<title>verbos espa&ntilde;oles</title>" << endl;
   t << "<style type=\"text/css\">" << endl;
 	t << "<!--" << endl;
- 	t << "h1 { font-size:48pt; color:#FF0000; font-family:Arial; text-align:center; }" << endl;
- 	t << ".n { font-size:12pt; color:#000000; font-family:Arial; margin:0pt; }" << endl;
- 	t << ".v   { font-size:16pt; color:#0000ff; font-family:Arial; }" << endl;
-	t << ".r   { font-size:16pt; color:#b0b0ff; font-family:Arial; }" << endl; 	
- 	t << ".t { background-color:#f0f0f0; padding:4pt; font-size:12pt; color:#000000; font-family:Arial; margin:0pt; }" << endl;
-	t << "td { background-color:#ffffff; padding:4pt; font-size:12pt; color:#000000; font-family:Arial; margin:0pt; }" << endl;
+ 	t << "h1 { font-size:48pt; color:#FF0000; font-family:sans-serif; text-align:center; }" << endl;
+ 	t << ".n { font-size:12pt; color:#000000; font-family:sans-serif; margin:0pt; }" << endl;
+ 	t << ".v   { font-size:16pt; color:#0000ff; font-family:sans-serif; }" << endl;
+	t << ".r   { font-size:16pt; color:#b0b0ff; font-family:sans-serif; }" << endl; 	
+ 	t << ".t { background-color:#f0f0f0; padding:4pt; font-size:12pt; color:#000000; font-family:sans-serif; margin:0pt; }" << endl;
+	t << "td { background-color:#ffffff; padding:4pt; font-size:12pt; color:#000000; font-family:sans-serif; margin:0pt; }" << endl;
  	t << "//-->" << endl;
   t << "</style>" << endl;
   t << "</head>" << endl;
@@ -484,7 +484,7 @@ bool KVerbosDoc::saveDocHTML(QFile &f)
   else
   {
     spanishVerbList::Iterator it;
-    for (it = verbList2.begin(); it != verbList2.end(); it++)
+    for (it = verbList2.begin(); it != verbList2.end(); ++it)
     {
     	// erst die spanische und die deutsche Bedeutung abspeichern und den Typ
      	t << "<hr color=#000000 size=3 noshade>" << endl;
@@ -627,7 +627,7 @@ bool KVerbosDoc::saveDocVERBOS(QFile &f)
   else
   {
     spanishVerbList::Iterator it;
-    for (it = verbList2.begin(); it!=verbList2.end(); it++)
+    for (it = verbList2.begin(); it!=verbList2.end(); ++it)
     {
     	// erst die spanische und die deutsche Bedeutung abspeichern und den Typ
    		t << (*it).getSpanish() << endl;
