@@ -1,16 +1,14 @@
 /***************************************************************************
 
-    $Id: kva_query.cpp,v 1.33 2004/07/13 13:35:25 annma Exp $
-
                        query parts of kvoctrain
 
     -----------------------------------------------------------------------
 
-    begin                : Thu Mar 11 20:50:53 MET 1999
+    begin          : Thu Mar 11 20:50:53 MET 1999
 
-    copyright            : (C) 1999-2001 Ewald Arnold
-                           (C) 2001 The KDE-EDU team
-    email                : kvoctrain@ewald-arnold.de
+    copyright      : (C) 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
+                     (C) 2001 The KDE-EDU team
+                     (C) 2005 Peter Hedlund <peter.hedlund@kdemail.net>
 
     -----------------------------------------------------------------------
 
@@ -21,12 +19,13 @@
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
 
 #include <kdebug.h>
+#include <klocale.h>
 
 #include "kvoctrain.h"
 #include "query-dialogs/RandomQueryDlg.h"
@@ -35,8 +34,7 @@
 #include "query-dialogs/ArtQueryDlg.h"
 #include "query-dialogs/AdjQueryDlg.h"
 #include "query-dialogs/SimpleQueryDlg.h"
-
-#include "queryoption-dialogs/QueryOptionsDlg.h"
+#include "prefs.h"
 
 #define MAX_QUERY_TIMEOUT 3
 
@@ -54,9 +52,9 @@ static const char not_contain[] = I18N_NOOP(
     "any expressions for the type of query you requested.\n"
     "Most likely, you should adjust your settings referring to "
     "thresholds and blocking values in the query options:\n"
-    "should the query options dialog be invoked now?");
-
+    "should the configuration dialog be invoked now?");
 
+/*
 void kvoctrainApp::slotQueryOptions()
 {
    slotQueryOptions(-1);
@@ -67,25 +65,24 @@ void kvoctrainApp::slotQueryOptions(int pageindex)
 {
    vector<int> old_liq = doc->getLessonsInQuery();
    QueryOptionsDlg qodlg (
-                    maxqueryTime /1000,
-                    showcounter,
-                    type_querytimeout,
+                    Prefs::maxTimePer() /1000,
+                    Prefs::showCounter(),
                     doc,
                     lessons,
                     &querymanager,
-                    swap_querydir,
-                    suggestions,
-                    split,
-                    periods,
-                    colons,
-                    semicolons,
-                    commas,
-                    fields,
-                    show_more,
-                    i_know,
-                    alt_learn,
-                    block,
-                    expire,
+                    Prefs::swapDirection(),
+                    Prefs::suggestions(),
+                    Prefs::split(),
+                    Prefs::periods(),
+                    Prefs::colons(),
+                    Prefs::semicolons(),
+                    Prefs::commas(),
+                    Prefs::fields(),
+                    Prefs::showMore(),
+                    Prefs::iKnow(),
+                    Prefs::altLearn(),
+                    Prefs::block(),
+                    Prefs::expire(),
                     presettings);
 
    if (pageindex >= 0)
@@ -94,23 +91,23 @@ void kvoctrainApp::slotQueryOptions(int pageindex)
    int res = qodlg.exec();
    if (res == QDialog::Accepted) {
 
-      type_querytimeout = qodlg.getTypeQueryTimeout();
-      maxqueryTime = qodlg.getMQueryTime()*1000;
-      showcounter = qodlg.getShowCounter();
+      //type_querytimeout = qodlg.getTypeQueryTimeout();
+      Prefs::setMaxTimePer(qodlg.getMQueryTime()*1000);
+      Prefs::setShowCounter(qodlg.getShowCounter());
       querymanager = qodlg.getQueryManager();
-      swap_querydir = qodlg.getSwapDir();
-      suggestions = qodlg.getSuggestions();
-      split = qodlg.getSplit();
-      periods = qodlg.getPeriods();
-      colons = qodlg.getColons();
-      semicolons = qodlg.getSemicolons();
-      commas = qodlg.getCommas();
-      fields = qodlg.getFields();
-      show_more = qodlg.getShowMore();
-      i_know = qodlg.getIKnow();
-      alt_learn = qodlg.getAltLearn();
-      block = qodlg.getBlock();
-      expire = qodlg.getExpire();
+      Prefs::setSwapDirection(qodlg.getSwapDir());
+      Prefs::setSuggestions(qodlg.getSuggestions());
+      Prefs::setSplit(qodlg.getSplit());
+      Prefs::setPeriods(qodlg.getPeriods());
+      Prefs::setColons(qodlg.getColons());
+      Prefs::setSemicolons(qodlg.getSemicolons());
+      Prefs::setCommas(qodlg.getCommas());
+      Prefs::setFields(qodlg.getFields());
+      Prefs::setShowMore(qodlg.getShowMore());
+      Prefs::setIKnow(qodlg.getIKnow());
+      Prefs::setAltLearn(qodlg.getAltLearn());
+      Prefs::setBlock(qodlg.getBlock());
+      Prefs::setExpire(qodlg.getExpire());
       presettings = qodlg.getPreSetting();
       if (old_liq != qodlg.getQueryManager().lessonItems()) {
         doc->setModified();
@@ -122,7 +119,7 @@ void kvoctrainApp::slotQueryOptions(int pageindex)
    }
 }
 
-
+*/
 void kvoctrainApp::slotStartPropertyQuery(int col, QueryType property)
 {
   removeEntryDlg();
@@ -162,7 +159,7 @@ void kvoctrainApp::slotStartPropertyQuery(int col, QueryType property)
     if( KMessageBox::Yes == KMessageBox::questionYesNo(this,
                                 i18n(not_contain),
                                 kapp->makeStdCaption(i18n("Starting Query"))))
-       slotQueryOptions(2);
+       slotGeneralOptionsPage(5);
      return;
   }
 
@@ -179,12 +176,8 @@ void kvoctrainApp::slotStartPropertyQuery(int col, QueryType property)
                            query_cycle,
                            query_num,
                            query_startnum,
-                           tablefont,
-			   exp,
-                           doc,
-                           maxqueryTime,
-                           showcounter,
-                           type_querytimeout);
+                           exp,
+                           doc);
 
   connect( simpleQueryDlg, SIGNAL(sigEditEntry(int,int)),
            this, SLOT(slotEditEntry(int,int)));
@@ -292,17 +285,14 @@ void kvoctrainApp::slotTimeOutProperty(QueryDlgBase::Result res)
                            query_num,
                            query_startnum,
                            exp,
-                           doc,
-                           maxqueryTime,
-                           showcounter,
-                           type_querytimeout);
+                           doc);
 
   simpleQueryDlg->initFocus();
   slotStatusMsg(IDS_DEFAULT);
 }
 
 
-void kvoctrainApp::slotStartTypeQuery(int col, QString type)
+void kvoctrainApp::slotStartTypeQuery(int col, const QString & type)
 {
   removeEntryDlg();
   slotStatusMsg(i18n("Starting special query..."));
@@ -340,7 +330,7 @@ void kvoctrainApp::slotStartTypeQuery(int col, QString type)
     if( KMessageBox::Yes == KMessageBox::questionYesNo(this,
                                 i18n(not_contain),
                                 kapp->makeStdCaption(i18n("Starting Query"))))
-       slotQueryOptions(2);
+       slotGeneralOptionsPage(5);
      return;
   }
 
@@ -356,14 +346,10 @@ void kvoctrainApp::slotStartTypeQuery(int col, QString type)
                             query_cycle,
                             query_num,
                             query_startnum,
-                            tablefont,
                             exp,
                             doc,
                             doc->getConjugation(act_query_col),
-                            exp->getConjugation(act_query_col),
-                            maxqueryTime,
-                            showcounter,
-                            type_querytimeout);
+                            exp->getConjugation(act_query_col));
 
     verbQueryDlg->initFocus();
     connect( verbQueryDlg, SIGNAL(sigEditEntry(int,int)),
@@ -380,13 +366,9 @@ void kvoctrainApp::slotStartTypeQuery(int col, QString type)
                           query_cycle,
                           query_num,
                           query_startnum,
-			  tablefont,
                           exp,
                           doc,
-                          doc->getArticle(act_query_col),
-                          maxqueryTime,
-                          showcounter,
-                          type_querytimeout);
+                          doc->getArticle(act_query_col));
     artQueryDlg->initFocus();
     connect( artQueryDlg, SIGNAL(sigEditEntry(int,int)),
              this, SLOT(slotEditEntry(int,int)));
@@ -401,13 +383,9 @@ void kvoctrainApp::slotStartTypeQuery(int col, QString type)
                           query_cycle,
                           query_num,
                           query_startnum,
-			  tablefont,
                           exp,
                           doc,
-                          exp->getComparison(act_query_col),
-                          maxqueryTime,
-                          showcounter,
-                          type_querytimeout);
+                          exp->getComparison(act_query_col));
     adjQueryDlg->initFocus();
     connect( adjQueryDlg, SIGNAL(sigEditEntry(int,int)),
               this, SLOT(slotEditEntry(int,int)));
@@ -523,10 +501,7 @@ void kvoctrainApp::slotTimeOutType(QueryDlgBase::Result res)
                             exp,
                             doc,
                             doc->getConjugation(act_query_col),
-                            exp->getConjugation(act_query_col),
-                            maxqueryTime,
-                            showcounter,
-                            type_querytimeout);
+                            exp->getConjugation(act_query_col));
 
     verbQueryDlg->initFocus();
   }
@@ -544,10 +519,7 @@ void kvoctrainApp::slotTimeOutType(QueryDlgBase::Result res)
                           query_startnum,
                           exp,
                           doc,
-                          doc->getArticle(act_query_col),
-                          maxqueryTime,
-                          showcounter,
-                          type_querytimeout);
+                          doc->getArticle(act_query_col));
     artQueryDlg->initFocus();
   }
   else if (queryType == QT_Comparison) {
@@ -564,10 +536,7 @@ void kvoctrainApp::slotTimeOutType(QueryDlgBase::Result res)
                           query_startnum,
                           exp,
                           doc,
-                          exp->getComparison(act_query_col),
-                          maxqueryTime,
-                          showcounter,
-                          type_querytimeout);
+                          exp->getComparison(act_query_col));
     adjQueryDlg->initFocus();
   }
   else {
@@ -589,7 +558,7 @@ void kvoctrainApp::slotRestartQuery()
 }
 
 
-void kvoctrainApp::slotStartQuery(QString translang, QString orglang, bool create_new)
+void kvoctrainApp::slotStartQuery(const QString & translang, const QString & orglang, bool create_new)
 {
   removeEntryDlg();
   slotStatusMsg(i18n("Starting random query..."));
@@ -615,8 +584,7 @@ void kvoctrainApp::slotStartQuery(QString translang, QString orglang, bool creat
   random_expr2.clear();
 
   if (create_new || queryList.size() == 0)
-    queryList = querymanager.select (doc, act_lesson, oindex, tindex,
-                                     swap_querydir, alt_learn, block, expire);
+    queryList = querymanager.select (doc, act_lesson, oindex, tindex);
 
   query_startnum = 0;
   if (queryList.size() > 0) {
@@ -639,7 +607,7 @@ void kvoctrainApp::slotStartQuery(QString translang, QString orglang, bool creat
     if( KMessageBox::Yes == KMessageBox::questionYesNo(this,
                                 i18n(not_contain),
                                 kapp->makeStdCaption(i18n("Starting Query"))))
-       slotQueryOptions(2);
+       slotGeneralOptionsPage(5);
      return;
   }
 
@@ -671,22 +639,8 @@ void kvoctrainApp::slotStartQuery(QString translang, QString orglang, bool creat
                              query_cycle,
                              query_num,
                              query_startnum,
-			     tablefont,
                              exp,
-                             doc,
-                             maxqueryTime,
-                             showcounter,
-                             type_querytimeout,
-                             suggestions,
-                             split,
-                             periods,
-                             colons,
-                             semicolons,
-                             commas,
-                             fields,
-                             show_more,
-                             i_know,
-                             swap_querydir);
+                             doc);
       randomQueryDlg->initFocus();
       connect( randomQueryDlg, SIGNAL(sigEditEntry(int,int)),
                this, SLOT(slotEditEntry(int,int)));
@@ -704,12 +658,8 @@ void kvoctrainApp::slotStartQuery(QString translang, QString orglang, bool creat
                              query_cycle,
                              query_num,
                              query_startnum,
-			     tablefont,
                              exp,
-                             doc,
-                             maxqueryTime,
-                             showcounter,
-                             type_querytimeout);
+                             doc);
       mcQueryDlg->initFocus();
       connect( mcQueryDlg, SIGNAL(sigEditEntry(int,int)),
                this, SLOT(slotEditEntry(int,int)));
@@ -776,7 +726,7 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
 
         //When you get it wrong Leisner style, it ends up in the back
         //of the line
-        if (alt_learn)
+        if (Prefs::altLearn())
           random_expr1.push_back (qer);
         else
           random_expr2.push_back (qer);
@@ -798,7 +748,7 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
 
       //When you get it wrong Leisner style, it ends up in the back
       //of the line
-      if (alt_learn)
+      if (Prefs::altLearn())
         random_expr1.push_back (qer);
       else
         random_expr2.push_back (qer);
@@ -815,7 +765,7 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
 
     case QueryDlgBase::Known :
       num_queryTimeout = 0;
-      if (alt_learn) {
+      if (Prefs::altLearn()) {
         //we always store the current question in the random_expr
         //array, so delete it from there.
         random_expr1.erase (random_expr1.begin() + random_query_nr);
@@ -836,7 +786,7 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
           //The user has answered correctly four times in a row. She
           //is good!
           exp->setInQuery(false);
-          
+
           query_num--;
           if (oindex == 0) {
             exp->incGrade(tindex, false);
@@ -860,7 +810,7 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
         }
 
       }
-      else { //not alt_learn
+      else { //not Prefs::altLearn()
       query_num--;
       if (query_cycle <= 1) {
         if (oindex == 0) {
@@ -902,7 +852,7 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
       return;
   }
 
-  if (alt_learn) {
+  if (Prefs::altLearn()) {
 
     if (correct_3_times.size() > 7 ||
         (correct_3_times.size() > 0
@@ -946,7 +896,7 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
     }
 
   }
-  else {  // not alt_learn
+  else {  // not Prefs::altLearn()
   if (random_expr1.size() == 0 ) {
     if (   random_expr2.size() == 0
         && queryList.size() == 0) {
@@ -971,7 +921,7 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
     slotStopQuery(true);
     return;
   }
-  
+
   random_query_nr = random.getLong(random_expr1.size());
   }
 
@@ -982,7 +932,7 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
   QString q_org,
           q_trans;
 
-  if (swap_querydir) {
+  if (Prefs::swapDirection()) {
     bool rand_swap = random.getBool();
 
     if (rand_swap) {        // random direction
@@ -991,8 +941,7 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
       tindex = tmp;
     }
 
-    if (!querymanager.validate (exp, act_lesson, oindex, tindex,
-                                block, expire)) {
+    if (!querymanager.validate (exp, act_lesson, oindex, tindex)) {
       int tmp = oindex;  // must use other direction which is the only valid
       oindex = tindex;
       tindex = tmp;
@@ -1023,10 +972,7 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
                              query_num,
                              query_startnum,
                              exp,
-                             doc,
-                             maxqueryTime,
-                             showcounter,
-                             type_querytimeout);
+                             doc);
       randomQueryDlg->initFocus();
   }
   else if (queryType == QT_Multiple) {
@@ -1044,10 +990,7 @@ void kvoctrainApp::slotTimeOutQuery(QueryDlgBase::Result res)
                          query_num,
                          query_startnum,
                          exp,
-                         doc,
-                         maxqueryTime,
-                         showcounter,
-                         type_querytimeout);
+                         doc);
       mcQueryDlg->initFocus();
   }
   slotStatusMsg(IDS_DEFAULT);
