@@ -4,13 +4,11 @@
 
     -----------------------------------------------------------------------
 
-    begin                : Thu Mar 11 20:50:53 MET 1999
+    begin          : Thu Mar 11 20:50:53 MET 1999
 
-    copyright            : (C) 1999-2001 Ewald Arnold
-                           (C) 2001 The KDE-EDU team
-                           (C) 2004-2005 Peter Hedlund
-
-    email                : kvoctrain@ewald-arnold.de
+    copyright      : (C) 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
+                     (C) 2001 The KDE-EDU team
+                     (C) 2004-2005 Peter Hedlund <peter.hedlund@kdemail.net>
 
     -----------------------------------------------------------------------
 
@@ -34,6 +32,7 @@
 #include <klocale.h>
 #include <kdebug.h>
 #include <kiconloader.h>
+#include <kprinter.h>
 
 #include <kinputdialog.h>
 #include <qtimer.h>
@@ -44,17 +43,17 @@
 #include <kvoctraincore.h>
 #include "kvoctrain.h"
 #include "entry-dialogs/EntryDlg.h"
-#include "option-dialogs/GeneralOptionsDlg.h"
 #include "docprop-dialogs/DocPropDlg.h"
 #include "docprop-dialogs/DocPropLangDlg.h"
 #include "statistik-dialogs/StatistikDlg.h"
+#include "common-dialogs/kvoctrainprefs.h"
 #include "prefs.h"
 
-void kvoctrainApp::slotSaveOptions()
+/*void kvoctrainApp::slotSaveOptions()
 {
    saveOptions(true);
 }
-
+*/
 
 kvoctrainApp::~kvoctrainApp()
 {
@@ -86,43 +85,35 @@ void kvoctrainApp::slotSelectAll ()
 void kvoctrainApp::slotCurrentCellChanged(int row, int col)
 {
   col -= KV_EXTRA_COLS;
+  bool noData = false;
+  kvoctrainExpr *expr;
 
   statusBar()->clear();
-  if (  doc->numEntries() <= row
-      ||doc->numLangs() <= col
-      || row < 0
-      || col < 0) {
-    if (rem_label != 0)
-      rem_label->setText  (i18n (PREFIX_Remark));
-    if (pron_label != 0)
-      pron_label->setText (i18n (PREFIX_Pronunce));
-    if (type_label != 0)
-      type_label->setText (i18n (PREFIX_Type));
-
-    if (entryDlg != 0) {
-      slotEditEntry(row, col+KV_EXTRA_COLS);
-      entryDlg->setEnabled(EntryDlg::EnableOnlyCommon);
-    }
-
-    return;
-  }
-
-  kvoctrainExpr *expr = doc->getEntry(row);
+  if (doc->numEntries() <= row || doc->numLangs() <= col || row < 0 || col < 0)
+    noData = true;
+  else
+    expr = doc->getEntry(row);
 
   if (rem_label != 0)
-    rem_label->setText( i18n(PREFIX_Remark) + expr->getRemark (col) );
+    rem_label->setText(i18n("Abbreviation for R)emark","R: %1")
+                       .arg(noData ? QString::null : expr->getRemark(col)));
   if (pron_label != 0)
-    pron_label->setText( i18n(PREFIX_Pronunce) + expr->getPronunce (col) );
+    pron_label->setText(i18n("Abbreviation for P)ronouncation","P: %1")
+                        .arg(noData ? QString::null : expr->getPronunce(col)));
   if (type_label != 0)
-    type_label->setText( i18n(PREFIX_Type)
-            + QueryManager::typeStr(expr->getType(col)) );
+    type_label->setText(i18n("Abbreviation for T)ype of word", "T: %1")
+                        .arg(noData ? QString::null : QueryManager::typeStr(expr->getType(col))));
 
   if (entryDlg != 0) {
-    if (col == 0)
-      entryDlg->setEnabled(EntryDlg::EnableOnlyOriginal);
-    else
-      entryDlg->setEnabled(EntryDlg::EnableAll);
-    slotEditEntry(row, col+KV_EXTRA_COLS);
+    if (noData)
+      entryDlg->setEnabled(EntryDlg::EnableOnlyCommon);
+    else {
+      if (col == 0)
+        entryDlg->setEnabled(EntryDlg::EnableOnlyOriginal);
+      else
+        entryDlg->setEnabled(EntryDlg::EnableAll);
+    }
+    slotEditEntry(row, col + KV_EXTRA_COLS);
   }
 }
 
@@ -143,7 +134,7 @@ void kvoctrainApp::slotEditCallBack(int res)
 
     case EntryDlg::EditApply:
       commitEntryDlg(true);
-      if (smartAppend)
+      if (Prefs::smartAppend())
       {
         int row = view->getTable()->currentRow();
         if (row == view->getTable()->numRows()-1)
@@ -185,7 +176,7 @@ void kvoctrainApp::commitEntryDlg(bool force)
      return;
    }
 
-   if (!force && entryDlg->isModified() && !autoentryApply) {
+   if (!force && entryDlg->isModified() && !Prefs::autoEntryApply()) {
      if( KMessageBox::No == KMessageBox::warningYesNo(this,
                    i18n("The entry dialog contains unsaved changes.\n"
                         "Do you want to apply or discard your changes?"),
@@ -246,12 +237,13 @@ void kvoctrainApp::commitEntryDlg(bool force)
              QueryManager::getMainType(entryDlg->getType()) )
            expr->setType(j, entryDlg->getType());
      }
-     expr->setLesson (entryDlg->getLesson());
+     expr->setLesson(entryDlg->getLesson());
      expr->setActive(entryDlg->getActive());
 
      entryDlg->setModified(false);
      doc->setModified(true);
      view->getTable()->updateCell(row, col+KV_EXTRA_COLS);
+     view->getTable()->updateCell(row, KV_COL_LESS);
    }
    else {
      col -= KV_EXTRA_COLS;
@@ -364,7 +356,7 @@ void kvoctrainApp::createEntryDlg(int row, int col)
                     querymanager,
                     title,
                     doc->getEntry(row)->isActive(),
-                    ipafont);
+                    Prefs::iPAFont());
    }
    else {
      col -= KV_EXTRA_COLS;
@@ -416,7 +408,7 @@ void kvoctrainApp::createEntryDlg(int row, int col)
                     querymanager,
                     title,
                     doc->getEntry(row)->isActive(),
-                    ipafont);
+                    Prefs::iPAFont());
    }
    connect( entryDlg, SIGNAL(sigEditChoice(int)),
              this, SLOT(slotEditCallBack(int)));
@@ -430,7 +422,6 @@ void kvoctrainApp::createEntryDlg(int row, int col)
 
    vector<QTableSelection> tabsel;
    entryDlg->setCell(row, col+KV_EXTRA_COLS, tabsel);
-   entryDlg->initFocus();
    entryDlg->show();
 }
 
@@ -575,6 +566,7 @@ void kvoctrainApp::setDataEntryDlg (int row, int col)
                        doc->getEntry(row)->isActive());
    }
    view->getTable()->updateCell(row, col);
+   view->getTable()->updateCell(row, KV_COL_LESS);
    vector<QTableSelection> tabsel;
    if (hasSel) {
      for (int i = 0; i < view->getTable()->numSelections(); ++i)
@@ -690,7 +682,6 @@ void kvoctrainApp::slotDocPropsLang ()
 void kvoctrainApp::slotModifiedDoc(bool mod)
 {
   setCaption(kapp->makeStdCaption(doc->getTitle(), false, doc->isModified()));
-  toolBar()->setItemEnabled(ID_FILE_SAVE, mod);
   slotStatusMsg(IDS_DEFAULT);
 }
 
@@ -708,9 +699,9 @@ bool kvoctrainApp::hasSelection()
 void kvoctrainApp::slotRemoveRow()
 {
   if (!hasSelection()) {
-    if( KMessageBox::Yes == KMessageBox::questionYesNo(this,
+    if( KMessageBox::Continue == KMessageBox::warningContinueCancel(this,
                   i18n("Do you really want to delete the selected entry?\n"),
-                  kapp->makeStdCaption("")))
+                  kapp->makeStdCaption(""),KStdGuiItem::del()))
     {
       KVocTrainTable *table = view->getTable();
       doc->removeEntry(table->currentRow());
@@ -719,9 +710,9 @@ void kvoctrainApp::slotRemoveRow()
     }
   }
   else {
-    if(KMessageBox::Yes == KMessageBox::questionYesNo(this,
+    if(KMessageBox::Continue == KMessageBox::warningContinueCancel(this,
                   i18n("Do you really want to delete the selected range?\n"),
-                  kapp->makeStdCaption("")))
+                  kapp->makeStdCaption(""),KStdGuiItem::del()))
     {
       KVocTrainTable *table = view->getTable();
 
@@ -881,7 +872,7 @@ void kvoctrainApp::slotCreateLesson(int header)
 
 void kvoctrainApp::slotShowStatist()
 {
-   StatistikDlg sdlg (langset, doc, &gradecols);
+   StatistikDlg sdlg (langset, doc);
    sdlg.exec();
 }
 
@@ -897,7 +888,7 @@ void kvoctrainApp::slotCleanVocabulary ()
    slotStatusMsg(IDS_DEFAULT);
 
    if (num != 0) {
-     view->setView(doc, langset, gradecols);
+     view->setView(doc, langset);
      QString s =
         i18n("1 entry with the same content has been found and removed.",
              "%n entries with the same content have been found and removed.", num);
@@ -912,14 +903,12 @@ void kvoctrainApp::slotCleanVocabulary ()
 void kvoctrainApp::slotCreateRandom()
 {
    bool ok = FALSE;
-   //shouldn't this dialog display the previous setting i.e Prefs::entriesPerLesson()?
-   int res = KInputDialog::getInteger(
-                i18n( "Entries in Lesson" ),
-                i18n( "Enter number of entries in lesson:" ), 1, 1, 1000, 1, &ok, this );
+   int res = KInputDialog::getInteger(i18n( "Entries in Lesson" ),
+                i18n( "Enter number of entries in lesson:" ), Prefs::entriesPerLesson(), 1, 1000, 1, &ok, this );
    if (!ok)
      return;
 
-   entriesPerLesson = res;
+   Prefs::setEntriesPerLesson(res);
 
    slotStatusMsg(i18n("Creating random lessons..."));
    QApplication::setOverrideCursor( waitCursor );
@@ -937,10 +926,10 @@ void kvoctrainApp::slotCreateRandom()
      s.setNum (less_no);
      s.insert (0, "- ");
      lessons->insertItem (s);
-     int less_cnt = entriesPerLesson;
+     int less_cnt = Prefs::entriesPerLesson();
      while (randomList.size () != 0) {
        if (--less_cnt <= 0) {
-         less_cnt = entriesPerLesson;
+         less_cnt = Prefs::entriesPerLesson();
          less_no++;
          s.setNum (less_no);
          s.insert (0, "- ");
@@ -971,73 +960,37 @@ void kvoctrainApp::slotGeneralOptions()
 
 void kvoctrainApp::slotGeneralOptionsPage(int index)
 {
-   QString defTrans;
-   GeneralOptionsDlg godlg (defTrans,
-                    separator,
-                    backupTime /(60*1000),
-                    langset,
-                    lastPixName,
-                    lessons,
-                    paste_order,
-                    useCurrent,
-                    doc,
-                    tablefont,
-                    ipafont,
-                    &querymanager,
-                    gradecols,
-                    header_resizer,
-                    smartAppend,
-                    autosaveopts,
-                    autoentryApply);
+  KVocTrainPrefs* dialog = new KVocTrainPrefs(langset, doc, lessons, &querymanager, this, "settings",  Prefs::self() );
+  connect(dialog, SIGNAL(settingsChanged()), this, SLOT(slotApplyPreferences()));
+  if (index >= 0)
+    dialog->selectPage(index);
+  dialog->show();
+}
 
-   if (index >= 0)
-     godlg.selectPage(index);
 
-   int res = godlg.exec();
-   if (res == QDialog::Accepted) {
+void kvoctrainApp::slotApplyPreferences()
+{
+  kdDebug() << "Prefs Update" << endl;
+  if (pron_label)
+    pron_label->setFont(Prefs::iPAFont());
+  view->getTable()->setFont(Prefs::tableFont());
+  view->getTable()->updateContents();
 
-      defTrans = godlg.getDefaultLang();
-      backupTime = godlg.getBackupTime()*60*1000;
-      smartAppend = godlg.getSmartAppend();
-      autosaveopts = godlg.getAutoSaveOpts();
-      autoentryApply = godlg.getAutoApply();
-      separator = godlg.getSeparator();
-      langset = godlg.getLangSet();
-      paste_order = godlg.getPasteOrder();
-      useCurrent = godlg.getUseCurrent(),
-      tablefont = godlg.getFont();
-      ipafont = godlg.getIPAFont();
-      gradecols = godlg.getGradeCols();
-      header_resizer = godlg.getResizer();
-
-       // rather ugly hack to keep useCurrent "globally" up to date
-      // is that necessary? anmma Feb 23rd 2004
-      Prefs::setUseCurrent( useCurrent);
-      Prefs::writeConfig();
-
-      if (pron_label)
-        pron_label->setFont(ipafont);
-      view->getTable()->setFont(tablefont);
-      view->setResizer (header_resizer);
-      view->getTable()->updateContents();
-
-      // update header buttons
-      for (int i = 0; i < (int) doc->numLangs(); i++) {
-        QString sid = i>0 ? doc->getIdent(i)
-                          : doc->getOriginalIdent();
-
-        int idx = langset.indexShortId(sid);
-        QString pm = "";
-        QString lid = sid;
-        if  (idx >= 0) {
-          lid = langset.longId(idx);
-          pm = langset.PixMapFile(idx);
-        }
-        view->setHeaderProp (i+KV_EXTRA_COLS, lid, pm);
-      }
-      configSaveOptions->setEnabled(!autosaveopts);
-      slotStatusMsg(IDS_DEFAULT);
-   }
+  readLanguages();
+  // update header buttons
+  for (int i = 0; i < (int) doc->numLangs(); i++)
+  {
+    QString sid = i>0 ? doc->getIdent(i): doc->getOriginalIdent();
+    int idx = langset.indexShortId(sid);
+    QString pm = "";
+    QString lid = sid;
+    if (idx >= 0)
+    {
+      lid = langset.longId(idx);
+      pm = langset.PixMapFile(idx);
+    }
+    view->setHeaderProp(i + KV_EXTRA_COLS, lid, pm);
+  }
 }
 
 
@@ -1052,7 +1005,7 @@ void kvoctrainApp::slotAppendLang(int header_and_cmd)
                         "Should this dialog be invoked now?");
     if( KMessageBox::Yes == KMessageBox::questionYesNo(this,
                   msg,
-                  kapp->makeStdCaption("")));
+                  kapp->makeStdCaption(""),i18n("Invoke Dialog"), i18n("Do Not Invoke")));
      {
        slotGeneralOptionsPage(1);
      }
@@ -1061,7 +1014,6 @@ void kvoctrainApp::slotAppendLang(int header_and_cmd)
 
    if (lang_id >= (int) langset.size())
      return;
-   kdDebug() << "I'm here" << endl;
    doc->appendLang("");
    int num = doc->numEntries()-1;
    for (int i = 0; i < (int) num; i++) {
@@ -1070,7 +1022,7 @@ void kvoctrainApp::slotAppendLang(int header_and_cmd)
    }
 
    doc->setIdent(doc->numLangs()-1, langset.shortId(lang_id));
-   view->setView(doc, langset, gradecols);
+   view->setView(doc, langset);
    doc->setModified();
 }
 
@@ -1084,7 +1036,6 @@ void kvoctrainApp::slotInitSearch()
 
 void kvoctrainApp::slotSearchNext()
 {
-  kdDebug() << "Searching..." << endl;
   slotResumeSearch(searchstr);
 }
 
@@ -1108,12 +1059,14 @@ void kvoctrainApp::slotResumeSearch(const QString& s)
   bool word_beg = controlActive;
   int idx = doc->search(s, view->getTable()->currentColumn()-KV_EXTRA_COLS, searchpos, -1, word_beg, false);
   if (idx >= 0) {
+    view->getTable()->clearSelection();
     view->getTable()->setCurrentRow(idx, view->getTable()->currentColumn());
     searchpos = idx+1;
   }
   else { // try again from beginning up to current pos
     int idx = doc->search(s, view->getTable()->currentColumn()-KV_EXTRA_COLS, 0, searchpos, word_beg, false);
     if (idx >= 0) {
+      view->getTable()->clearSelection();
       view->getTable()->setCurrentRow(idx, view->getTable()->currentColumn());
       searchpos = idx+1;
     }
@@ -1129,12 +1082,7 @@ void kvoctrainApp::slotResumeSearch(const QString& s)
 
 void kvoctrainApp::slotStatusMsg(const QString &/*text*/)
 {
-/*
-  ///////////////////////////////////////////////////////////////////
-  // change status message permanently
-  statusBar()->clear();
-  statusBar()->changeItem(text, ID_STATUS_MSG );
-*/
+//
 }
 
 
@@ -1192,11 +1140,11 @@ void kvoctrainApp::aboutToShowLearn()
         if((j = langset.indexShortId(doc->getIdent(i))) >= 0
            && !langset.PixMapFile(j).isEmpty()
            && !langset.longId(j).isEmpty() ) {
-          query_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("from %1").arg(main_names[i]),
+          query_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("From %1").arg(main_names[i]),
               (i << (16+8)) |  IDH_START_QUERY);  // hack: IDs => header-ids + cmd
         }
         else {
-          query_m->insertItem(i18n("from %1").arg(doc->getIdent(i)), (i << (16+8)) |  IDH_START_QUERY);
+          query_m->insertItem(i18n("From %1").arg(doc->getIdent(i)), (i << (16+8)) |  IDH_START_QUERY);
         }
       }
 
@@ -1210,11 +1158,11 @@ void kvoctrainApp::aboutToShowLearn()
         if((j = langset.indexShortId(doc->getIdent(i))) >= 0
            && !langset.PixMapFile(j).isEmpty()
            && !langset.longId(j).isEmpty() ) {
-          multiple_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("from %1").arg(main_names[i]),
+          multiple_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("From %1").arg(main_names[i]),
               (i << (16+8)) |  IDH_START_MULTIPLE);  // hack: IDs => header-ids + cmd
         }
         else {
-          multiple_m->insertItem(i18n("from %1").arg(doc->getIdent(i)), (i << (16+8)) |  IDH_START_MULTIPLE);
+          multiple_m->insertItem(i18n("From %1").arg(doc->getIdent(i)), (i << (16+8)) |  IDH_START_MULTIPLE);
         }
       }
       header_m->insertItem(SmallIconSet("run_multi"), i18n("Create &Multiple Choice"), multiple_m, (4 << 16) | IDH_NULL);
@@ -1371,6 +1319,19 @@ void kvoctrainApp::slotStatusHelpMsg(const QString &text)
     statusBar()->message(text, 3000);
 }
 
+void kvoctrainApp::slotFilePrint()
+{
+  slotStatusMsg(i18n("Printing..."));
+  KPrinter printer;
+  printer.setFullPage(true);
+  if (printer.setup(this))
+  {
+    view->print(&printer);
+  }
+
+  slotStatusMsg(i18n("Ready"));
+}
+
 #include "kvoctrain.moc"
 
 
