@@ -21,7 +21,7 @@
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
@@ -35,6 +35,7 @@
 #include <kio/netaccess.h>
 
 #include <qfileinfo.h>
+#include <qregexp.h>
 
 #include <algorithm>
 #include <functional>
@@ -46,6 +47,7 @@ using namespace std;
 #include <float.h>
 
 #include "kvoctraincore.h"
+#include "prefs.h"
 
 //********************************************************
 //  kvoctrainDoc
@@ -89,7 +91,7 @@ void kvoctrainDoc::Init ()
 }
 
 
-kvoctrainDoc::kvoctrainDoc(QObject *parent, const KURL& url, QString separator, QStringList *lang_order)
+kvoctrainDoc::kvoctrainDoc(QObject *parent, const KURL& url)
 {
   Init();
   if (!url.isEmpty())
@@ -135,10 +137,17 @@ kvoctrainDoc::kvoctrainDoc(QObject *parent, const KURL& url, QString separator,
         }
         break;
 
-        case csv:
+        case vt_voc:
         {
           QTextStream is (&f);
-          read = loadFromCsv (is, separator, lang_order);
+          read = loadFromVoc(is);
+        }
+        break;
+
+        case csv:
+        {
+          QTextStream is(&f);
+          read = loadFromCsv(is);
         }
         break;
 
@@ -178,8 +187,7 @@ kvoctrainDoc::~kvoctrainDoc()
 }
 
 
-bool kvoctrainDoc::saveAs (QObject *parent, const KURL & url, QString title, FileType ft, const QString &separator, 
-  QStringList *lang_order)
+bool kvoctrainDoc::saveAs (QObject *parent, const KURL & url, QString title, FileType ft)
 {
   connect( this, SIGNAL(progressChanged(kvoctrainDoc*,int)), parent, SLOT(slotProgress(kvoctrainDoc*,int)) );
 
@@ -189,7 +197,7 @@ bool kvoctrainDoc::saveAs (QObject *parent, const KURL & url, QString title, Fil
   if (title == doc_url.fileName())
     title = QString::null;
 
-  if (ft == automatic) 
+  if (ft == automatic)
   {
     if (tmp.path().right(strlen("." KVTML_EXT)) == "." KVTML_EXT)
       ft = kvtml;
@@ -199,7 +207,7 @@ bool kvoctrainDoc::saveAs (QObject *parent, const KURL & url, QString title, Fil
       ft = vt_vcb;
     else if (tmp.path().right(strlen("." CSV_EXT)) == "." CSV_EXT)
       ft = csv;
-    else 
+    else
     {
       tmp.setFileName(tmp.path() + "." KVTML_EXT);
       ft = kvtml;
@@ -240,7 +248,7 @@ bool kvoctrainDoc::saveAs (QObject *parent, const KURL & url, QString title, Fil
 
       case csv: {
         QTextStream os( &f );                       // serialize using f
-        saved = saveToCsv(os, title, separator, lang_order);
+        saved = saveToCsv(os, title);
       }
       break;
 
@@ -941,6 +949,9 @@ kvoctrainDoc::FileType kvoctrainDoc::detectFT(const QString &filename)
    if (line == LEX_IDENT_50)
      return vt_lex;
 
+   if (c1 == '"' && (line.contains('"') == 1 || line.contains(QRegExp("\",[0-9]"))))
+     return vt_voc;
+
    return csv;
 }
 
